@@ -85,10 +85,10 @@ class Spreadclient:
         else:
             raise InvalidMethod("Invalid Column identifier")
 
-        active_col = [i[col_index] for i in self.listed]
+        active_col = [i[col_index-1] for i in self.listed]
         if value in active_col:
             return self.listed[active_col.index(value)],active_col.index(value)+1
-        return []
+        return [],None
 
     def search_listed(self,value,mode="static",limits=None):
         if mode == "dynamic":
@@ -122,15 +122,20 @@ class Spreadclient:
     def append_toupdate(self,position,value):
         # Syntax: new row F dynamic
         if str(position).startswith("new row"):
+            print("Detected appending New ROw")
             if position.endswith("dynamic"):
                 a1_not = f"{position.split()[2].upper()}{len(self.sheet.col_values(1))+1}"
             elif position.endswith("static"):
                 a1_not = f"{position.split()[2].upper()}{len(self.listed)+1}"
 
         elif str(position[0]).isalpha() and str(position[-1]).isdigit():
+            print("Detected appending by A1")
             a1_not = position
         elif len(position)==2 and type(position[0])==int and type(position[1])==int:
+            print("Detected appending by Row Col")
             a1_not = gspread.utils.rowcol_to_a1(position[0],position[1])
+        else:
+            print("No Mode DETECTED",position,value)
         row,col = gspread.utils.a1_to_rowcol(a1_not)
         element = gspread.models.Cell(row=row,col=col,value=value)
         self.to_update.append(element)
